#!/usr/bin/python2.7
# -*- coding: utf-8 -*-
#
# Univention Management Console module:
#   Kaspersky Mail Security
#
# Copyright 2014 Univention GmbH
#
# http://www.univention.de/
#
# All rights reserved.
#
# The source code of this program is made available
# under the terms of the GNU Affero General Public License version 3
# (GNU AGPL V3) as published by the Free Software Foundation.
#
# Binary versions of this program provided by Univention to you as
# well as other copyrighted, protected or trademarked materials like
# Logos, graphics, fonts, specific documentations and configurations,
# cryptographic keys etc. are subject to a license agreement between
# you and Univention and not subject to the GNU AGPL V3.
#
# In the case you use this program under the terms of the GNU AGPL V3,
# the program is provided in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License with the Debian GNU/Linux or Univention distribution in file
# /usr/share/common-licenses/AGPL-3; if not, see
# <http://www.gnu.org/licenses/>.

import uuid
import subprocess

from univention.lib.i18n import Translation
from univention.management.console.modules import UMC_OptionTypeError, Base
from univention.management.console.log import MODULE
from univention.management.console.protocol.definitions import *

import univention.config_registry
from univention.config_registry.frontend import ucr_update

_ = Translation( 'univention-management-console-module-klms' ).translate

class Instance( Base ):
    def init(self):
        # this initialization method is called when the module process is created
        pass

    def _run_it(self, services, action):
        failed = []
        for srv in services:
            if subprocess.call(('/usr/sbin/invoke-rc.d', srv, action)):
                failed.append(srv)
        return failed

    def _set_webui_password(self, password):
        MODULE.warn( 'klms._set_webui_password: setting password ' )

        error = "";
        p = subprocess.Popen(("/opt/kaspersky/klms/bin/klms-control", "--set-web-admin-password", password), stderr=subprocess.PIPE)

        p.wait()

        if p.returncode != 0:
            error = p.stderr.read()
            return (MODULE_ERR, error)

        return (SUCCESS, error)

    def enable (self, request):
        MODULE.warn( 'klms.enable: options: %s' % repr( request.options ) )

	# hack to be able to translate this string
	_error = _("ERROR: Auth: The following requirements are applied to the password:\n(1) it cannot be empty;\n(2) it must include ASCII characters only;\n(3) it must be at least 8 characters long;\n(4) it must contain symbols of at least 3 of the following kinds: an uppercase letter, a lowercase letter, a number, a special symbol.");

        message = _("Successfully saved settings")

        ucr = univention.config_registry.ConfigRegistry()
        ucr.load()

        if request.options["enable"] == True:
            MODULE.warn("enabling KLMS")
            ucr_update(ucr, { "klms/enabled": "yes", "mail/antivir": "no" })
        else:
            MODULE.warn("disabling KLMS")
            ucr_update(ucr, { "klms/enabled": "no", "mail/antivir": "yes" })

        self._run_it(["postfix"], "reload")

        ret = (SUCCESS, None);
        if request.options["password"] != "":
            ret = self._set_webui_password(request.options["password"])

        request.status = SUCCESS
        if ret[0] != SUCCESS:
            request.status = MODULE_ERR
            message = _(ret[1].rstrip())

        self.finished(request.id, {'success': True}, message)

